/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.ow2.petals.binding.soap;

import java.util.HashMap;
import java.util.Map;

import org.ow2.petals.component.framework.ComponentConfiguration;

/**
 * The SOAP component properties
 *
 * @author Christophe HAMERLING - eBMWebSourcing
 *
 */
public class SoapProperties {

    public static final String HTTP_PORT = "http.port";

    public static final String ENABLE_SERVICES_LIST = "http.services.list";

    public static final String SERVICES_CONTEXT = "http.services.context";

    public static final String SERVICES_MAPPING = "http.services.mapping";

    public static final String THREAD_HTTP_MAX_POOL_SIZE = "http.thread.pool.size.max";

    public static final String THREAD_HTTP_MIN_POOL_SIZE = "http.thread.pool.size.min";

    public static final String HTTP_ACCEPTORS = "http.acceptors";

    public static final int DEFAULT_HTTP_PORT = 8084;

    public static final boolean DEFAULT_ENABLE_SERVICES_LIST = true;

    public static final String DEFAULT_PROTOCOL = "http";

    public static final String DEFAULT_SERVICES_CONTEXT = "petals";

    public static final String DEFAULT_SERVICES_MAPPING = "services";

    public static final int DEFAULT_HTTP_THREAD_MAX_POOL_SIZE = 255;

    public static final int DEFAULT_HTTP_THREAD_MIN_POOL_SIZE = 1;

    public static final int DEFAULT_HTTP_ACCEPTORS = 4;

    private ComponentConfiguration componentConfiguration;

    /**
     * Creates a new instance of {@link SoapProperties}
     *
     * @param properties
     */
    public SoapProperties(ComponentConfiguration componentConfiguration) {
        this.componentConfiguration = componentConfiguration;
    }

    /**
     * Get the HTTP port
     *
     * @return
     */
    public int getHttpPort() {
        return Integer.parseInt(componentConfiguration.getProperties()
                .getProperty(HTTP_PORT, Integer.toString(DEFAULT_HTTP_PORT)));
    }

    /**
     * Does the component have to provide the services list
     *
     * @return
     */
    public boolean isProvidingServicesList() {
        return Boolean.parseBoolean(componentConfiguration.getProperties()
                .getProperty(ENABLE_SERVICES_LIST,
                        Boolean.toString(DEFAULT_ENABLE_SERVICES_LIST)));
    }

    public String getServicesContext() {
        return componentConfiguration.getProperties().getProperty(
                SERVICES_CONTEXT, DEFAULT_SERVICES_CONTEXT);
    }

    public String getServicesMapping() {
        return componentConfiguration.getProperties().getProperty(
                SERVICES_MAPPING, DEFAULT_SERVICES_MAPPING);
    }

    /**
     * Currently support only http protocol
     *
     * @return
     */
    public String getProtocol() {
        return DEFAULT_PROTOCOL;
    }

    /**
     * Get the thread max pool size of the Jetty server
     *
     * @return
     */
    public int getHttpThreadMaxPoolSize() {
        return Integer.parseInt(componentConfiguration.getProperties()
                .getProperty(THREAD_HTTP_MAX_POOL_SIZE,
                        Integer.toString(DEFAULT_HTTP_THREAD_MAX_POOL_SIZE)));
    }

    /**
     * Get the thread min pool size of the Jetty server
     *
     * @return
     */
    public int getHttpThreadMinPoolSize() {
        return Integer.parseInt(componentConfiguration.getProperties()
                .getProperty(THREAD_HTTP_MIN_POOL_SIZE,
                        Integer.toString(DEFAULT_HTTP_THREAD_MIN_POOL_SIZE)));
    }

    /**
     * Get the number of acceptors of the Jetty server
     *
     * @return
     */
    public int getHttpAcceptors() {
        return Integer.parseInt(componentConfiguration.getProperties()
                .getProperty(HTTP_ACCEPTORS,
                        Integer.toString(DEFAULT_HTTP_ACCEPTORS)));
    }

    /**
     * Get the default component properties
     *
     * @return
     */
    protected static Map<String, String> getDefaultProperties() {
        Map<String, String> result = new HashMap<String, String>(2);
        result.put(HTTP_PORT, Integer.toString(DEFAULT_HTTP_PORT));
        result.put(ENABLE_SERVICES_LIST, Boolean
                .toString(DEFAULT_ENABLE_SERVICES_LIST));
        result.put(SERVICES_CONTEXT, DEFAULT_SERVICES_CONTEXT);
        result.put(SERVICES_MAPPING, DEFAULT_SERVICES_MAPPING);
        result.put(THREAD_HTTP_MAX_POOL_SIZE, Integer
                .toString(DEFAULT_HTTP_THREAD_MAX_POOL_SIZE));
        result.put(THREAD_HTTP_MIN_POOL_SIZE, Integer
                .toString(DEFAULT_HTTP_THREAD_MIN_POOL_SIZE));
        result.put(HTTP_ACCEPTORS, Integer.toString(DEFAULT_HTTP_ACCEPTORS));

        return result;
    }

}
