/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.ow2.petals.binding.soap.listener;

import java.util.Properties;

import static org.ow2.petals.component.framework.Constants.Component.TIMEOUT;


/**
 * @author chamerling - eBM Websourcing
 *
 */
public class SUProperties {

    /**
     * Delete of not the root element of the soap message on incoming calls. Add
     * or not a root element on outgoing soap message.
     */
    public static final String ROOT_ELEMENT = "root-element";

    public static final String SOAP_ACTION = "soap-action";

    public static final String ADDRESS = "address";

    /**
     * The soap version of the outgoing message. Default is 1.1.
     */
    public static final String SOAP_VERSION = "soap-version";

    public static final String PROXY_HOST = "proxy-host";

    public static final String PROXY_PORT = "proxy-port";

    public static final String PROXY_USER = "proxy-user";

    public static final String PROXY_PASSWORD = "proxy-password";

    public static final String PROXY_DOMAIN = "proxy-domain";

    public static final String TOPIC_PREFIX = "topic";

    /**
     * Basic authentication username
     */
    public static final String BASIC_AUTH_USERNAME = "authentication.basic.username";

    /**
     * Basic authentication password
     */
    public static final String BASIC_AUTH_PASSWORD = "authentication.basic.password";

    /**
     * Add a root element on outgoing soap messages.
     */
    public static final String ADD_ROOT = "add-root";

    /**
     * Remove the root element from incoming soap messages before building the
     * normalized message.
     */
    public static final String REMOVE_ROOT = "remove-root";

    /**
     * Creates a new instance if {@link SUProperties}
     */
    protected SUProperties() {
        super();
    }

    /**
     * Get the topic name from the address extension.
     *
     * @param value
     * @return
     */
    public static String getTopicNameFromExtensionAddress(final String address) {
        String result = "";
        if (SUProperties.isTopicAddress(address)) {
            result = address.substring(address.indexOf(":") + 1, address
                    .length());
        }
        return result;
    }

    /**
     * Test if the given address is a topic address (starts with topic:).
     *
     * @param address
     * @return
     */
    public static final boolean isTopicAddress(final String address) {
        return (address != null && address.startsWith(TOPIC_PREFIX + ":"));
    }

    /**
     * Retrieve the timeout element extension value
     *
     * @param extensionProperties
     * @return The timeout value set in extensions. The default value is
     *         returned if no valid value is set or if no value is set.
     */
    public final static long retrieveTimeOut(
            final Properties extensionProperties, final long defaultValue) {

        final String tmp = extensionProperties
                .getProperty(TIMEOUT);
        long result = defaultValue;

        try {
            result = (tmp == null ? defaultValue : Long.parseLong(tmp));
        } catch (NumberFormatException e) {
            // NOP
        }

        return result;
    }

    /**
     * Retrieve the remove root element extension value
     *
     * @param extensionProperties
     * @return
     */
    public final static boolean retrieveRemoveRootElement(
            final Properties extensionProperties, final boolean defaultValue) {

        final String tmp = extensionProperties
                .getProperty(SUProperties.REMOVE_ROOT);

        return tmp == null ? defaultValue : Boolean.parseBoolean(tmp);
    }
}
