/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.ow2.petals.binding.soap.listener.outgoing;

import java.net.URI;

import javax.jbi.messaging.MessagingException;
import javax.xml.namespace.QName;

import org.apache.axis2.AxisFault;
import org.apache.axis2.client.ServiceClient;
import org.apache.axis2.description.AxisOperation;
import org.apache.axis2.description.AxisService;
import org.apache.axis2.description.OutInAxisOperation;
import org.apache.axis2.description.OutOnlyAxisOperation;
import org.apache.axis2.description.RobustOutOnlyAxisOperation;
import org.ow2.petals.binding.soap.listener.incoming.PetalsAxisService;
import org.ow2.petals.component.framework.Constants.MEPConstants;
import org.ow2.petals.component.framework.util.IDGenerator;

/**
 * @author chamerling - eBM WebSourcing
 *
 */
public class Axis2Utils {

    /**
     * Counter used to generate the service client name.
     */
    private static Counter serviceCounter = new Counter();

    /**
     * Creates a new instance of {@link Axis2Utils}
     *
     */
    private Axis2Utils() {
    }

    /**
     * Create a ServiceClient with an AxisService set with the good operation
     *
     * @param mep
     *            the message exchange pattern used. Non null
     * @param operation
     *            the target operation QName. Non null
     * @return a ServiceClient. Not null.
     * @throws HandlingException
     */
    public static ServiceClient createServiceClient(URI mep, QName operation)
            throws MessagingException {
        ServiceClient client = null;

        AxisService service = new AxisService(
                PetalsAxisService.OUTGOING_SERVICE_CLIENT_PREFIX
                        + IDGenerator.getNewID()
                        + serviceCounter.incrementAndGet());

        AxisOperation axisOperation = null;
        if (MEPConstants.IN_ONLY_PATTERN.value().equals(mep)) {
            axisOperation = new OutOnlyAxisOperation(operation);
        } else if (MEPConstants.ROBUST_IN_ONLY_PATTERN.value().equals(mep)) {
            axisOperation = new RobustOutOnlyAxisOperation(operation);
        } else if (MEPConstants.IN_OPTIONAL_OUT_PATTERN.value().equals(mep)
                || MEPConstants.IN_OUT_PATTERN.value().equals(mep)) {
            axisOperation = new OutInAxisOperation(operation);
        }
        service.addOperation(axisOperation);

        try {
            client = new ServiceClient(null, service);
        } catch (AxisFault e) {
            throw new MessagingException("Can't create ServiceClient", e);
        }
        return client;
    }
}
